pub type DecryptedRoomKeyBundleEvent = DecryptedOlmV1Event<RoomKeyBundleContent>;Expand description
An io.element.msc4268.room_key_bundle to-device event which has
been decrypted using using the m.olm.v1.curve25519-aes-sha2 algorithm
Aliased Type
pub struct DecryptedRoomKeyBundleEvent {
pub sender: OwnedUserId,
pub recipient: OwnedUserId,
pub keys: OlmV1Keys,
pub recipient_keys: OlmV1Keys,
pub sender_device_keys: Option<DeviceKeys>,
pub content: RoomKeyBundleContent,
}Fields
sender: OwnedUserIdThe sender of the event, as set by the sender of the event.
recipient: OwnedUserIdThe intended recipient of the event, as set by the sender of the event.
keys: OlmV1KeysThe sender’s signing keys of the encrypted event.
recipient_keys: OlmV1KeysThe recipient’s signing keys of the encrypted event.
sender_device_keys: Option<DeviceKeys>The device keys if supplied as per MSC4147
content: RoomKeyBundleContentThe type of the event.